@@ -1,6 +1,6 @@
 package Games::Domino::Params;
 
-$Games::Domino::Params::VERSION   = '0.21';
+$Games::Domino::Params::VERSION   = '0.22';
 $Games::Domino::Params::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Games::Domino::Params - Placeholder for parameters for Games::Domino.
 
 =head1 VERSION
 
-Version 0.21
+Version 0.22
 
 =cut
 
@@ -45,7 +45,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Games-Domino>
+L<https://github.com/manwar/Games-Domino>
 
 =head1 BUGS
 
